==> httraqt_1.2.0.orig.tar.gz: httraqt/sources/main/includes/AboutDialog.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2013 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef ABOUT_H
#define ABOUT_H

#include "ui_AboutDialog.h"


class HTTraQt;

#define DONATE_STR "https://www.paypal.com/cgi-bin/webscr?cmd=_xclick&business=eduard_kalinowski@yahoo.de"
#define HTTRACK_STR "http://www.httrack.com"
#define HTTRAQT_STR "http://httraqt.sourceforge.net"

class AboutDialog: public QDialog, public Ui_AboutDialog
{
        Q_OBJECT
    public:
        AboutDialog(QWidget *parent = 0, Qt::WFlags fl = 0);


    private:
        void translate();

    private:
        HTTraQt* parent;
};

#endif

==> httraqt_1.3.0.orig.tar.gz: httraqt/sources/main/includes/AboutDialog.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef ABOUT_H
#define ABOUT_H

#include "httraqt.h"
#include "ui_AboutDialog.h"


class HTTraQt;

#define DONATE_STR "https://www.paypal.com/cgi-bin/webscr?cmd=_xclick&business=eduard_kalinowski@yahoo.de"
#define HTTRACK_STR "http://www.httrack.com"
#define HTTRAQT_STR "http://httraqt.sourceforge.net"

class AboutDialog: public QDialog, public Ui_AboutDialog, public Translator
{
        Q_OBJECT
    public:
        AboutDialog(QWidget *parent = 0, Qt::WindowFlags fl = 0);


    private:
        void translateDialog();

    private:
        HTTraQt* parent;
};

#endif
